@@ -52,7 +52,7 @@ try:
     # test if dbus-x11 is installed
     bus = dbus.SessionBus()
 except Exception:
-    print str(exceptions.DbusNotSupported())
+    print _('D-Bus is not present on this machine or python module is missing')
     sys.exit(1)
 
 OBJ_PATH = '/org/gajim/dbus/RemoteObject'
@@ -339,7 +339,8 @@ class GajimRemote:
         Print retrieved result to the output
         """
         if res is not None:
-            if self.command in ('open_chat', 'send_chat_message', 'send_single_message', 'start_chat'):
+            if self.command in ('open_chat', 'send_chat_message',
+            'send_single_message', 'start_chat'):
                 if self.command in ('send_message', 'send_single_message'):
                     self.argv_len -= 2
 
